*******************
Authors and Credits
*******************

Authors
=======

* Marten van Kerkwijk (@mhvk)
* Jing Luo (@luojing1211)
* Chenchong Charles Zhu (@cczhu)

Other contributors (alphabetical)
=================================

* Rebecca Lin (@00rebe)
* Nikhil Mahajan (@theXYZT)
* Luke Pratley (@Luke-Pratley)

We also acknowledge the automatic pull requests triggered by Pey Lian
Lim (@pllim) which help keep astropy-related packages, including
Baseband-tasks, up to date.

If you have contributed to Baseband-tasks but are not listed above, please send
one of the authors an e-mail, or `open a pull request for this page
<https://github.com/mhvk/baseband-tasks/edit/master/AUTHORS.rst>`_.
